@@ -4,8 +4,8 @@ from modeller import gbsa
 from modeller.scripts import complete_pdb
 
 
-def EvoEF_run(pdb, qc, ic, wt_evo_score = 0.0):
-    cmd = f"Evoef/EvoEF --command=ComputeBinding --split={qc},{ic} --pdb={pdb}|tail -n2"
+def EvoEF_run(pdb, qc, ic, wt_evo_score = 0.0, evoef_path = ""):
+    cmd = f"{evoef_path}/EvoEF --command=ComputeBinding --split={qc},{ic} --pdb={pdb}|tail -n2"
     p = subprocess.run(cmd, shell = True,check = True, stdout=subprocess.PIPE, universal_newlines=True)
     try:
         score = p.stdout.split()[2]
@@ -15,19 +15,17 @@ def EvoEF_run(pdb, qc, ic, wt_evo_score = 0.0):
         score = "nan"
     return score
 
-def Foldx_run(mutant, qc,ic, mutant_folder="./", wt_foldx_score = 0.0):
-    return 0
-# def Foldx_run(mutant, qc,ic, mutant_folder="./", wt_foldx_score = 0.0):
-#     out = subprocess.run(f"foldx --command=AnalyseComplex --analyseComplexChains={qc},{ic} --pdb={mutant} --pdb-dir={mutant_folder} --output-dir=tmp/ |tail -n 7|head -n 1 ", shell = True,stdout=subprocess.PIPE, universal_newlines = True)
-#     try:
-#         out = out.stdout
-#         out = str(out)
-#         mutant_dg = float(out.split()[2])
-#         score = mutant_dg - wt_foldx_score
-#         score = round(score, 3)
-#     except:
-#         score = "nan"
-#     return score
+def Foldx_run(mutant, qc,ic, mutant_folder="./", wt_foldx_score = 0.0, foldx_path = ""):
+    out = subprocess.run(f"{foldx_path}/foldx --command=AnalyseComplex --analyseComplexChains={qc},{ic} --pdb={mutant} --pdb-dir={mutant_folder} --output-dir=tmp/ |tail -n 7|head -n 1 ", shell = True,stdout=subprocess.PIPE, universal_newlines = True)
+    try:
+        out = out.stdout
+        out = str(out)
+        mutant_dg = float(out.split()[2])
+        score = mutant_dg - wt_foldx_score
+        score = round(score, 3)
+    except:
+        score = "nan"
+    return score
 
 def GBSA(pdb,qc: str,ic: str ,wt_gbsa = 0.0):
     log.none()
